==> consumer-library-2.0.0-20131014.151102-154-sources.jar: org/gcube/messaging/common/consumerlibrary/query/PredefinedQueries.java <==
package org.gcube.messaging.common.consumerlibrary.query;

/**
 * 
 * @author Andrea Manzi(CERN)
 *
 */

public class PredefinedQueries {
	
	public final static String BASEQUERY="SELECT PORTALACCOUNTING.user AS user, PORTALACCOUNTING.vre as vre, " +
			" PORTALACCOUNTING.Id AS Id, PORTALACCOUNTING.date AS date, PORTALACCOUNTING.time AS time, " +
			"PORTALACCOUNTING.type AS type, ";
	
	/** *  LOGINQUERY*/ 
	 
	public final static String LOGINQUERY = BASEQUERY +
			"LOGIN.message AS message FROM PORTALACCOUNTING,LOGIN WHERE PORTALACCOUNTING.type='LoginRecord'" +
			" AND PORTALACCOUNTING.Id=LOGIN.Id";
	/** *  SIMPLESEARCHQUERY*/ 
	public final static String SIMPLESEARCHQUERY =BASEQUERY +
			"SIMPLESEARCH.termValue AS termValue FROM PORTALACCOUNTING,SIMPLESEARCH WHERE PORTALACCOUNTING.type='SimpleSearchRecord'" +
			" AND PORTALACCOUNTING.Id=SIMPLESEARCH.Id";
	/** *  BROWSEQUERY*/ 
	public final static String BROWSEQUERY = BASEQUERY+
			"BROWSE.browseBy AS browseBy, BROWSE.isDistinct AS isDistinct FROM PORTALACCOUNTING, BROWSE" +
			" WHERE PORTALACCOUNTING.type='BrowseRecord' AND PORTALACCOUNTING.Id=BROWSE.Id";
	/** *  ADVANCEDSEARCHQUERY*/ 
	public final static String ADVANCEDSEARCHQUERY = BASEQUERY+
			"ADVANCEDSEARCH.operator AS operator  FROM PORTALACCOUNTING,ADVANCEDSEARCH WHERE PORTALACCOUNTING.type='AdvancedSearchRecord' " +
			"AND PORTALACCOUNTING.Id=ADVANCEDSEARCH.Id";
	/** *  CONTENTQUERY*/ 
	public final static String CONTENTQUERY = BASEQUERY+
			"CONTENT.identifier AS identifier, CONTENT.name AS name  FROM  PORTALACCOUNTING, CONTENT WHERE PORTALACCOUNTING.type='ContentRecord' " +
			"AND PORTALACCOUNTING.Id=CONTENT.Id";
	/** *  GENERICQUERY*/ 
	public final static String GENERICQUERY = BASEQUERY+
			"GENERIC.message AS message  FROM  PORTALACCOUNTING, GENERIC WHERE PORTALACCOUNTING.type='GenericRecord' " +
			"AND PORTALACCOUNTING.Id=GENERIC.Id";
	
	public final static String QUICKSEARCHQUERY = BASEQUERY+
			"QUICKSEARCH.termValue AS termValue  FROM  PORTALACCOUNTING, QUICKSEARCH WHERE PORTALACCOUNTING.type='QuickSearchRecord' " +
			"AND PORTALACCOUNTING.Id=QUICKSEARCH.Id";
	
	public final static String GOOGLESEARCHQUERY = BASEQUERY+
			"GOOGLESEARCH.termValue AS termValue  FROM  PORTALACCOUNTING, GOOGLESEARCH WHERE PORTALACCOUNTING.type='GoogleSearchRecord' " +
			"AND PORTALACCOUNTING.Id=GOOGLESEARCH.Id";
	
	public final static String HLQUERY = BASEQUERY+"HL.IDENTIFIER AS IDENTIFIER, HL.NAME AS NAME, HL.TYPE AS HL_TYPE, HL.SUBTYPE AS SUBTYPE " +
			"FROM  PORTALACCOUNTING, HL WHERE PORTALACCOUNTING.type='HLRecord' " +
			"AND PORTALACCOUNTING.Id=HL.Id";
	
	public final static String AISQUERY = BASEQUERY+"AIS.IDENTIFIER AS IDENTIFIER, AIS.NAME AS NAME, AIS.SUBTYPE AS SUBTYPE FROM PORTALACCOUNTING, AIS" +
			" WHERE PORTALACCOUNTING.type='AISRecord' AND PORTALACCOUNTING.Id=AIS.Id";
	
	public final static String TSQUERY = BASEQUERY+"TS.TITLE AS TITLE, TS.SUBTYPE AS SUBTYPE   FROM  PORTALACCOUNTING, TS" +
			" WHERE PORTALACCOUNTING.type='TSRecord' " +
			"AND PORTALACCOUNTING.Id=TS.Id";
	
	public final static String ANNOTATIONQUERY = BASEQUERY+"ANNOTATION.NAME AS NAME, ANNOTATION.ACTION AS ACTION,ANNOTATION.SUBTYPE AS SUBTYPE  FROM  PORTALACCOUNTING, ANNOTATION" +
			" WHERE PORTALACCOUNTING.type='AnnotationRecord' " +
			"AND PORTALACCOUNTING.Id=ANNOTATION.Id";
	
	public final static String REPORTQUERY = BASEQUERY+"REPORT.SUBTYPE AS SUBTYPE, REPORT.TEMPLATEID AS TEMPLATEID, REPORT.TEMPLATENAME AS TEMPLATENAME, REPORT.AUTHOR AS AUTHOR, REPORT.NAME AS NAME, REPORT.MIMETYPE AS MIMETYPE, REPORT.TYPE AS TYPE  FROM  PORTALACCOUNTING, REPORT" +
			" WHERE PORTALACCOUNTING.type='ReportRecord' " +
			"AND PORTALACCOUNTING.Id=REPORT.Id";
	
	public final static String WORKFLOWDOCUMENTQUERY = BASEQUERY+"DOCUMENTWORKFLOW.SUBTYPE AS SUBTYPE, DOCUMENTWORKFLOW.WORKFLOWID AS WORKFLOWID,DOCUMENTWORKFLOW.REPORTNAME AS REPORTNAME,DOCUMENTWORKFLOW.STATUS AS STATUS,DOCUMENTWORKFLOW.STEPNUMBER AS STEPNUMBER  FROM  PORTALACCOUNTING, DOCUMENTWORKFLOW" +
			" WHERE PORTALACCOUNTING.type='DocumentWorkflowRecord' " +
			"AND PORTALACCOUNTING.Id=DOCUMENTWORKFLOW.Id";
	
	public final static String WEBAPPQUERY = BASEQUERY+"WEBAPP.SUBTYPE AS SUBTYPE  FROM  PORTALACCOUNTING, WEBAPP" +
			" WHERE PORTALACCOUNTING.type='WebAppRecord' " +
			"AND PORTALACCOUNTING.Id=WEBAPP.Id";
	
	public final static String WARQUERY = BASEQUERY+"WAR.SUBTYPE AS SUBTYPE,WAR.WARID AS WARID,WAR.WARNAME AS WARNAME,WAR.WEBAPPNAME AS WEBAPPNAME, WAR.WEBAPPVERSION AS WEBAPPVERSION, WAR.CATEGORY AS CATEGORY FROM  PORTALACCOUNTING, WAR" +
			" WHERE PORTALACCOUNTING.type='WarRecord' " +
			"AND PORTALACCOUNTING.Id=WAR.Id";
	
	public final static String AQUAMAPSQUERY = BASEQUERY+"AQUAMAPS.TITLE AS TITLE, AQUAMAPS.AQUAMAPSTYPE AS AQUAMAPSTYPE,AQUAMAPS.SUBTYPE AS SUBTYPE,AQUAMAPS.SPECIESCOUNT AS SPECIESCOUNT ,AQUAMAPS.GIS AS GIS,AQUAMAPS.HSPECID AS HSPECID,AQUAMAPS.OBJECTID AS OBJECTID    FROM  PORTALACCOUNTING, AQUAMAPS" +
			" WHERE PORTALACCOUNTING.type='AquamapsRecord' " +
			"AND PORTALACCOUNTING.Id=AQUAMAPS.Id";
	
	
	/** *  COLLECTIONQUERY*/ 
	public final static String COLLECTIONQUERY = "SELECT * FROM COLLECTION WHERE Id='***ID***' ";
	/** *  ADRESSEES QUERY*/ 
	public final static String ADDRESSESSQUERY = "SELECT * FROM GCUBEUSERSADDRESSEES WHERE Id='***ID***' ";
	/** *  GHNDETAIL QUERY*/ 
	public final static String GHNDETAILQUERY = "SELECT * FROM GHNDETAIL WHERE Id='***ID***' ";
	/** *  WEBAPPDETAIL QUERY*/ 
	public final static String WEBAPPDETAILQUERY = "SELECT * FROM WEBAPPDETAIL WHERE Id='***ID***' ";
	/** *  TERMQUERY*/ 
	public final static String TERMQUERY = "SELECT * FROM TERM WHERE Id='***ID***'";
	/** *  CONTENTNAME*/ 
	public final static String CONTENTNAME = "SELECT * FROM CONTENT WHERE Id='***ID***'";
	/** *  COUNT*/ 
	public final static String COUNTQUERY = "SELECT COUNT(Id) AS CNT FROM PORTALACCOUNTING WHERE type='***TYPE***'";
	/** *  COUNT WITH GROUP*/ 
	public final static String COUNTWITHGROUPQUERY = "SELECT COUNT(Id) AS CNT, ***GROUPBY*** AS GRP FROM PORTALACCOUNTING";
	
	
}

==> consumer-library-2.2.0-20151118.234301-332-sources.jar: org/gcube/messaging/common/consumerlibrary/query/PredefinedQueries.java <==
package org.gcube.messaging.common.consumerlibrary.query;

/**
 * 
 * @author Andrea Manzi(CERN)
 *
 */

public class PredefinedQueries {
	
	public final static String BASEQUERY="SELECT PORTALACCOUNTING.user AS user, PORTALACCOUNTING.vre as vre, " +
			" PORTALACCOUNTING.Id AS Id, PORTALACCOUNTING.date AS date, PORTALACCOUNTING.time AS time, " +
			"PORTALACCOUNTING.type AS type, ";
	
	/** *  LOGINQUERY*/ 
	 
	public final static String LOGINQUERY = BASEQUERY +
			"LOGIN.message AS message FROM PORTALACCOUNTING,LOGIN WHERE PORTALACCOUNTING.type='LoginRecord'" +
			" AND PORTALACCOUNTING.Id=LOGIN.Id";
	/** *  SIMPLESEARCHQUERY*/ 
	public final static String SIMPLESEARCHQUERY =BASEQUERY +
			"SIMPLESEARCH.termValue AS termValue FROM PORTALACCOUNTING,SIMPLESEARCH WHERE PORTALACCOUNTING.type='SimpleSearchRecord'" +
			" AND PORTALACCOUNTING.Id=SIMPLESEARCH.Id";
	/** *  BROWSEQUERY*/ 
	public final static String BROWSEQUERY = BASEQUERY+
			"BROWSE.browseBy AS browseBy, BROWSE.isDistinct AS isDistinct FROM PORTALACCOUNTING, BROWSE" +
			" WHERE PORTALACCOUNTING.type='BrowseRecord' AND PORTALACCOUNTING.Id=BROWSE.Id";
	/** *  ADVANCEDSEARCHQUERY*/ 
	public final static String ADVANCEDSEARCHQUERY = BASEQUERY+
			"ADVANCEDSEARCH.operator AS operator  FROM PORTALACCOUNTING,ADVANCEDSEARCH WHERE PORTALACCOUNTING.type='AdvancedSearchRecord' " +
			"AND PORTALACCOUNTING.Id=ADVANCEDSEARCH.Id";
	/** *  CONTENTQUERY*/ 
	public final static String CONTENTQUERY = BASEQUERY+
			"CONTENT.identifier AS identifier, CONTENT.name AS name  FROM  PORTALACCOUNTING, CONTENT WHERE PORTALACCOUNTING.type='ContentRecord' " +
			"AND PORTALACCOUNTING.Id=CONTENT.Id";
	/** *  GENERICQUERY*/ 
	public final static String GENERICQUERY = BASEQUERY+
			"GENERIC.message AS message  FROM  PORTALACCOUNTING, GENERIC WHERE PORTALACCOUNTING.type='GenericRecord' " +
			"AND PORTALACCOUNTING.Id=GENERIC.Id";
	
	public final static String QUICKSEARCHQUERY = BASEQUERY+
			"QUICKSEARCH.termValue AS termValue  FROM  PORTALACCOUNTING, QUICKSEARCH WHERE PORTALACCOUNTING.type='QuickSearchRecord' " +
			"AND PORTALACCOUNTING.Id=QUICKSEARCH.Id";
	
	public final static String GOOGLESEARCHQUERY = BASEQUERY+
			"GOOGLESEARCH.termValue AS termValue  FROM  PORTALACCOUNTING, GOOGLESEARCH WHERE PORTALACCOUNTING.type='GoogleSearchRecord' " +
			"AND PORTALACCOUNTING.Id=GOOGLESEARCH.Id";
	
	public final static String HLQUERY = BASEQUERY+"HL.IDENTIFIER AS IDENTIFIER, HL.NAME AS NAME, HL.TYPE AS HL_TYPE, HL.SUBTYPE AS SUBTYPE " +
			"FROM  PORTALACCOUNTING, HL WHERE PORTALACCOUNTING.type='HLRecord' " +
			"AND PORTALACCOUNTING.Id=HL.Id";
	
	public final static String AISQUERY = BASEQUERY+"AIS.IDENTIFIER AS IDENTIFIER, AIS.NAME AS NAME, AIS.SUBTYPE AS SUBTYPE FROM PORTALACCOUNTING, AIS" +
			" WHERE PORTALACCOUNTING.type='AISRecord' AND PORTALACCOUNTING.Id=AIS.Id";
	
	public final static String TSQUERY = BASEQUERY+"TS.TITLE AS TITLE, TS.SUBTYPE AS SUBTYPE   FROM  PORTALACCOUNTING, TS" +
			" WHERE PORTALACCOUNTING.type='TSRecord' " +
			"AND PORTALACCOUNTING.Id=TS.Id";
	
	public final static String ANNOTATIONQUERY = BASEQUERY+"ANNOTATION.NAME AS NAME, ANNOTATION.ACTION AS ACTION,ANNOTATION.SUBTYPE AS SUBTYPE  FROM  PORTALACCOUNTING, ANNOTATION" +
			" WHERE PORTALACCOUNTING.type='AnnotationRecord' " +
			"AND PORTALACCOUNTING.Id=ANNOTATION.Id";
	
	public final static String REPORTQUERY = BASEQUERY+"REPORT.SUBTYPE AS SUBTYPE, REPORT.TEMPLATEID AS TEMPLATEID, REPORT.TEMPLATENAME AS TEMPLATENAME, REPORT.AUTHOR AS AUTHOR, REPORT.NAME AS NAME, REPORT.MIMETYPE AS MIMETYPE, REPORT.TYPE AS TYPE  FROM  PORTALACCOUNTING, REPORT" +
			" WHERE PORTALACCOUNTING.type='ReportRecord' " +
			"AND PORTALACCOUNTING.Id=REPORT.Id";
	
	public final static String WORKFLOWDOCUMENTQUERY = BASEQUERY+"DOCUMENTWORKFLOW.SUBTYPE AS SUBTYPE, DOCUMENTWORKFLOW.WORKFLOWID AS WORKFLOWID,DOCUMENTWORKFLOW.REPORTNAME AS REPORTNAME,DOCUMENTWORKFLOW.STATUS AS STATUS,DOCUMENTWORKFLOW.STEPNUMBER AS STEPNUMBER  FROM  PORTALACCOUNTING, DOCUMENTWORKFLOW" +
			" WHERE PORTALACCOUNTING.type='DocumentWorkflowRecord' " +
			"AND PORTALACCOUNTING.Id=DOCUMENTWORKFLOW.Id";
	
	public final static String WEBAPPQUERY = BASEQUERY+"WEBAPP.SUBTYPE AS SUBTYPE  FROM  PORTALACCOUNTING, WEBAPP" +
			" WHERE PORTALACCOUNTING.type='WebAppRecord' " +
			"AND PORTALACCOUNTING.Id=WEBAPP.Id";
	
	public final static String WARQUERY = BASEQUERY+"WAR.SUBTYPE AS SUBTYPE,WAR.WARID AS WARID,WAR.WARNAME AS WARNAME,WAR.WEBAPPNAME AS WEBAPPNAME, WAR.WEBAPPVERSION AS WEBAPPVERSION, WAR.CATEGORY AS CATEGORY FROM  PORTALACCOUNTING, WAR" +
			" WHERE PORTALACCOUNTING.type='WarRecord' " +
			"AND PORTALACCOUNTING.Id=WAR.Id";
	
	public final static String AQUAMAPSQUERY = BASEQUERY+"AQUAMAPS.TITLE AS TITLE, AQUAMAPS.AQUAMAPSTYPE AS AQUAMAPSTYPE,AQUAMAPS.SUBTYPE AS SUBTYPE,AQUAMAPS.SPECIESCOUNT AS SPECIESCOUNT ,AQUAMAPS.GIS AS GIS,AQUAMAPS.HSPECID AS HSPECID,AQUAMAPS.OBJECTID AS OBJECTID    FROM  PORTALACCOUNTING, AQUAMAPS" +
			" WHERE PORTALACCOUNTING.type='AquamapsRecord' " +
			"AND PORTALACCOUNTING.Id=AQUAMAPS.Id";
	
	public final static String SMQUERY = BASEQUERY+"SM.SUBTYPE AS SUBTYPE,SM.FILENAME AS FILENAME ,SM.FILETYPE AS FILETYPE,SM.ALGORITHMNAME AS ALGORITHMNAME,SM.EXECUTIONOUTCOME AS EXECUTIONOUTCOME, SM.EXECUTIONTIME AS EXECUTIONTIME    FROM  PORTALACCOUNTING, SM" +
			" WHERE PORTALACCOUNTING.type='StatisticalManagerRecord' " +
			"AND PORTALACCOUNTING.Id=SM.Id";
	
	/** *  COLLECTIONQUERY*/ 
	public final static String COLLECTIONQUERY = "SELECT * FROM COLLECTION WHERE Id='***ID***' ";
	/** *  ADRESSEES QUERY*/ 
	public final static String ADDRESSESSQUERY = "SELECT * FROM GCUBEUSERSADDRESSEES WHERE Id='***ID***' ";
	/** *  GHNDETAIL QUERY*/ 
	public final static String GHNDETAILQUERY = "SELECT * FROM GHNDETAIL WHERE Id='***ID***' ";
	/** *  WEBAPPDETAIL QUERY*/ 
	public final static String WEBAPPDETAILQUERY = "SELECT * FROM WEBAPPDETAIL WHERE Id='***ID***' ";
	/** *  TERMQUERY*/ 
	public final static String TERMQUERY = "SELECT * FROM TERM WHERE Id='***ID***'";
	/** *  CONTENTNAME*/ 
	public final static String CONTENTNAME = "SELECT * FROM CONTENT WHERE Id='***ID***'";
	/** *  COUNT*/ 
	public final static String COUNTQUERY = "SELECT COUNT(Id) AS CNT FROM PORTALACCOUNTING WHERE type='***TYPE***'";
	/** *  COUNT WITH GROUP*/ 
	public final static String COUNTWITHGROUPQUERY = "SELECT COUNT(Id) AS CNT, ***GROUPBY*** AS GRP FROM PORTALACCOUNTING";
	
	
}
